# v0.1.0 (2026-01-07)

## 💫 New features

- more user-friendly reporting of user errors [[f2539bd0]](https://github.com/datalad/datasalad/commit/f2539bd0)
- enable default operation with the public ntfy.sh [[98b31c74]](https://github.com/datalad/datasalad/commit/98b31c74)

## 🐛 Bug Fixes

- skip timestamp recording when no notifications have been fetched [[b9184d96]](https://github.com/datalad/datasalad/commit/b9184d96)
- create state dir if not existing [[5cc84b94]](https://github.com/datalad/datasalad/commit/5cc84b94)
- output non-errors to STDOUT [[e5082166]](https://github.com/datalad/datasalad/commit/e5082166)
- minor typing issues [[d1676ef7]](https://github.com/datalad/datasalad/commit/d1676ef7)

## 🏠 Refactorings

- remove obsolete means of running the script [[ae6539a4]](https://github.com/datalad/datasalad/commit/ae6539a4)

## 📝 Documentation

- rough function descriptions, info on template placeholders [[db64268c]](https://github.com/datalad/datasalad/commit/db64268c)
- on running repeatedly via a cronjob [[7d48024d]](https://github.com/datalad/datasalad/commit/7d48024d)
- more complete README [[cd38f174]](https://github.com/datalad/datasalad/commit/cd38f174)
- on configuration [[901e8ea1]](https://github.com/datalad/datasalad/commit/901e8ea1)

## 🛡 Tests

- verify commits after the inital one [[d4429ffc]](https://github.com/datalad/datasalad/commit/d4429ffc)
